"""
Camera modules.
TODO: write doc
"""
__title__ = 'Cameras'

from .basecamera import BaseCamera
#from .adaptive import AdaptiveCamera
from .dummycamera import DummyCamera
